@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -95,7 +103,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
         final String metaValue_bo = "Tibetan";
         final String metaValue_vai = "Vai";
         final Object[][] data = new Object[][] {
-            { "001", "Mundo" },
+            { "001", "mundo" },
             { "002", "Africa" },
             { "003", "Hilagang Amerika" },
             { "005", "Timog Amerika" },
@@ -177,6 +185,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "CN", "China" },
             { "CO", "Colombia" },
             { "CP", "Clipperton Island" },
+            { "CQ", "Sark" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Cape Verde" },
@@ -471,10 +480,10 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "kr", "Kanuri" },
             { "ks", "Kashmiri" },
-            { "ku", "Kurdish" },
+            { "ku", "Kurmanji" },
             { "kv", "Komi" },
             { "kw", "Cornish" },
-            { "ky", "Kirghiz" },
+            { "ky", "Kyrgyz" },
             { "la", metaValue_la },
             { "lb", "Luxembourgish" },
             { "lg", "Ganda" },
@@ -553,7 +562,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "tw", "Twi" },
             { "ty", "Tahitian" },
             { "ug", "Uyghur" },
-            { "uk", "Ukranian" },
+            { "uk", "Ukrainian" },
             { "ur", "Urdu" },
             { "uz", "Uzbek" },
             { "ve", "Venda" },
@@ -584,6 +593,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "ast", "Asturian" },
             { "atj", "Atikamekw" },
             { "awa", "Awadhi" },
+            { "bal", "Baluchi" },
             { "ban", "Balinese" },
             { "bas", "Basaa" },
             { "bem", "Bemba" },
@@ -616,7 +626,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "crm", "Moose Cree" },
             { "crr", "Carolina Algonquian" },
             { "crs", "Seselwa Creole French" },
-            { "csw", "Latian na Cree" },
+            { "csw", "Swampy Cree" },
             { "dak", "Dakota" },
             { "dar", "Dargwa" },
             { "dav", "Taita" },
@@ -721,7 +731,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "moh", "Mohawk" },
             { "mos", "Mossi" },
             { "mua", "Mundang" },
-            { "mul", "Maramihang Wika" },
+            { "mul", "Maramihang wika" },
             { "mus", "Creek" },
             { "mwl", "Mirandese" },
             { "myv", "Erzya" },
@@ -883,28 +893,27 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "Zxxx", "Hindi Nakasulat" },
             { "Zyyy", "Karaniwan" },
             { "Zzzz", "Hindi Kilalang Script" },
-            { "de_AT", "Austrian German" },
-            { "de_CH", "Swiss High German" },
             { "en_US", "Ingles (American)" },
             { "es_ES", "European Spanish" },
             { "es_MX", "Mexican na Espanyol" },
             { "fa_AF", "Dari" },
-            { "fr_CH", "Swiss na French" },
             { "nl_BE", "Flemish" },
-            { "pt_BR", "Portuges ng Brasil" },
             { "pt_PT", "European Portuguese" },
             { "ro_MD", "Moldavian" },
             { "sw_CD", "Congo Swahili" },
-            { "ar_001", "Modernong Karaniwang Arabic" },
+            { "ar_001", "Modern Standard Arabic" },
             { "es_419", "Latin American na Espanyol" },
             { "key.ca", "Kalendaryo" },
             { "key.cf", "Format ng Pera" },
             { "key.co", "Pagkakasunud-sunod ng Ayos" },
             { "key.cu", "Pera" },
+            { "key.em", "Presentation ng Emoji" },
             { "key.hc", "Siklo ng Oras (12 laban sa 24)" },
-            { "key.lb", "Istilo ng Putol ng Linya" },
+            { "key.lb", "CJK na Line Break" },
+            { "key.lw", "Mga Line Break sa Mga Salita" },
             { "key.ms", "Sistema ng Pagsukat" },
             { "key.nu", "Mga Numero" },
+            { "key.ss", "Sentence Break Pagkatapos ng Abbr." },
             { "key.tz", "Time Zone" },
             { "key.va", "Lokal na Variant" },
             { "nds_NL", "Low Saxon" },
@@ -957,7 +966,7 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "type.nu.mymr", "Mga Myanmar na Digit" },
             { "type.nu.nkoo", "N’Ko na Mga Digit" },
             { "type.nu.olck", "Mga Digit ng Ol Chiki" },
-            { "type.nu.orya", "Mga Oriya na Digit" },
+            { "type.nu.orya", "Mga Odia na Digit" },
             { "type.nu.taml", "Tamil na Mga Numeral" },
             { "type.nu.telu", "Mga Telugu na Digit" },
             { "type.nu.thai", "Mga Thai na Digit" },
@@ -985,11 +994,10 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "type.ms.metric", "Metrikong Sistema" },
             { "type.nu.native", "Mga Native na Digit" },
             { "type.ca.chinese", "Kalendaryong Chinese" },
-            { "type.ca.islamic", "Kalendaryong Islam" },
-            { "type.ca.iso8601", "ISO-8601 na Kalendaryo" },
+            { "type.ca.islamic", "Kalendaryong Hijiri" },
+            { "type.ca.iso8601", "Kalendaryong Gregorian (Unang Taon)" },
             { "type.ca.persian", "Kalendaryong Persian" },
             { "type.cf.account", "Format ng Pera sa Accounting" },
-            { "type.co.big5han", "Pagkakasunod-sunod ng Pag-uuri ng Tradisyunal na Chinese - Big5" },
             { "type.d0.npinyin", "Numeric" },
             { "type.nu.arabext", "Extendend Arabic-Indic na Mga Digit" },
             { "type.nu.armnlow", "Armenian Lowercase Numerals" },
@@ -1020,7 +1028,6 @@ public class LocaleNames_fil extends OpenListResourceBundle {
             { "type.nu.mymrtlng", "Myanmar Tai Laing na Mga Digit" },
             { "type.nu.romanlow", "Roman Lowercase na Mga Numeral" },
             { "type.ca.gregorian", "Gregorian na Kalendaryo" },
-            { "type.co.gb2312han", "Pagkakasunud-sunod ng Pag-uuri ng Pinasimpleng Chinese - GB2312" },
             { "type.co.phonebook", "Pagkakasunud-sunod ng Pag-uuri ng Phonebook" },
             { "type.co.dictionary", "Pagkakasunud-sunod ng Pag-uuri ng Diksyunaryo" },
             { "type.co.traditional", "Tradisyunal na Pagkakasunud-sunod ng Pag-uuri" },
